pub struct PollFd<T>(/* private fields */)
where
T: AsFd;runtime only.Expand description
Implementations
Sourceimpl<T> PollFd<T>where
T: AsFd + 'static,
impl<T> PollFd<T>where
T: AsFd + 'static,
Sourcepub async fn accept(&self) -> Result<(PollFd<Socket>, SockAddr), Error>
Available on crate feature net only.
pub async fn accept(&self) -> Result<(PollFd<Socket>, SockAddr), Error>
net only.Accept a connection from this socket.
Sourcepub fn poll_accept(
&self,
cx: &mut Context<'_>,
) -> Poll<Result<(PollFd<Socket>, SockAddr), Error>>
Available on crate feature net only.
pub fn poll_accept( &self, cx: &mut Context<'_>, ) -> Poll<Result<(PollFd<Socket>, SockAddr), Error>>
net only.Poll to accept a connection from this socket.
Sourcepub async fn connect(&self, addr: &SockAddr) -> Result<(), Error>
Available on crate feature net only.
pub async fn connect(&self, addr: &SockAddr) -> Result<(), Error>
net only.Connect this socket to the specified address.
Sourcepub async fn accept_ready(&self) -> Result<(), Error>
Available on crate feature net only.
pub async fn accept_ready(&self) -> Result<(), Error>
net only.Wait for accept readiness, before calling accept, or after accept
returns WouldBlock.
Sourcepub async fn connect_ready(&self) -> Result<(), Error>
Available on crate feature net only.
pub async fn connect_ready(&self) -> Result<(), Error>
net only.Wait for connect readiness.
Sourcepub async fn read_ready(&self) -> Result<(), Error>
Available on crate feature net only.
pub async fn read_ready(&self) -> Result<(), Error>
net only.Wait for read readiness.
Sourcepub async fn write_ready(&self) -> Result<(), Error>
Available on crate feature net only.
pub async fn write_ready(&self) -> Result<(), Error>
net only.Wait for write readiness.
Sourcepub fn poll_accept_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
Available on crate feature net only.
pub fn poll_accept_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
net only.Poll for accept readiness.
Sourcepub fn poll_connect_ready(
&self,
cx: &mut Context<'_>,
) -> Poll<Result<(), Error>>
Available on crate feature net only.
pub fn poll_connect_ready( &self, cx: &mut Context<'_>, ) -> Poll<Result<(), Error>>
net only.Poll for connect readiness.
Sourcepub fn poll_read_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
Available on crate feature net only.
pub fn poll_read_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
net only.Poll for read readiness.
Sourcepub fn poll_write_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
Available on crate feature net only.
pub fn poll_write_ready(&self, cx: &mut Context<'_>) -> Poll<Result<(), Error>>
net only.Poll for write readiness.
Sourcepub fn poll_accept_with<R>(
&self,
cx: &mut Context<'_>,
f: impl FnMut(&T) -> Result<R, Error>,
) -> Poll<Result<R, Error>>
Available on crate feature net only.
pub fn poll_accept_with<R>( &self, cx: &mut Context<'_>, f: impl FnMut(&T) -> Result<R, Error>, ) -> Poll<Result<R, Error>>
net only.Poll for accept readiness and call the provided function.
Sourceimpl<T> PollFd<T>where
T: AsFd + 'static,
impl<T> PollFd<T>where
T: AsFd + 'static,
Sourcepub fn poll_read(
&self,
cx: &mut Context<'_>,
buf: &mut [u8],
) -> Poll<Result<usize, Error>>
Available on crate feature net only.
pub fn poll_read( &self, cx: &mut Context<'_>, buf: &mut [u8], ) -> Poll<Result<usize, Error>>
net only.Poll for read readiness and read data.
Sourcepub fn poll_read_vectored(
&self,
cx: &mut Context<'_>,
bufs: &mut [IoSliceMut<'_>],
) -> Poll<Result<usize, Error>>
Available on crate feature net only.
pub fn poll_read_vectored( &self, cx: &mut Context<'_>, bufs: &mut [IoSliceMut<'_>], ) -> Poll<Result<usize, Error>>
net only.Poll for read readiness and read data into a slice of buffers.
Sourcepub fn poll_read_buf(
&self,
cx: &mut Context<'_>,
buf: BorrowedCursor<'_, u8>,
) -> Poll<Result<(), Error>>
Available on crate features net and read_buf only.
pub fn poll_read_buf( &self, cx: &mut Context<'_>, buf: BorrowedCursor<'_, u8>, ) -> Poll<Result<(), Error>>
net and read_buf only.Poll for read readiness and read data into an uninitialized buffer.
Sourceimpl<T> PollFd<T>where
T: AsFd + 'static,
impl<T> PollFd<T>where
T: AsFd + 'static,
Sourcepub fn poll_write(
&self,
cx: &mut Context<'_>,
buf: &[u8],
) -> Poll<Result<usize, Error>>
Available on crate feature net only.
pub fn poll_write( &self, cx: &mut Context<'_>, buf: &[u8], ) -> Poll<Result<usize, Error>>
net only.Poll for write readiness and write data.
Sourcepub fn poll_write_vectored(
&self,
cx: &mut Context<'_>,
bufs: &[IoSlice<'_>],
) -> Poll<Result<usize, Error>>
Available on crate feature net only.
pub fn poll_write_vectored( &self, cx: &mut Context<'_>, bufs: &[IoSlice<'_>], ) -> Poll<Result<usize, Error>>
net only.Poll for write readiness and write data from a slice of buffers.
Whether this is more efficient than poll_write depends on the
source: it is a single writev for sockets and files, while other
sources may fall back to writing the first non-empty buffer.